@@ -286,7 +286,7 @@ class Step(Node):
         Parameters
         ----------
         supplier
-            Other node that supplies to thise node.
+            Other node that supplies to this node.
 
         Returns
         -------
@@ -295,6 +295,9 @@ class Step(Node):
         """
         idep = super().add_supplier(supplier)
         if self.get_mandatory() != Mandatory.NO:
+            # Loop over steps supplying to the supplying file,
+            # i.e. two edges up in the graph (step -> file -> step),
+            # and make them required.
             for step in supplier.suppliers(Step):
                 step.make_required()
         return idep
@@ -382,8 +385,17 @@ class Step(Node):
         sql = "SELECT rescheduled_info FROM step WHERE node = ?"
         return self.con.execute(sql, (self.i,)).fetchone()[0]
 
-    def set_rescheduled_info(self, info: str):
-        self.con.execute("UPDATE step SET rescheduled_info = ? WHERE node = ?", (info, self.i))
+    def add_rescheduled_info(self, info: str):
+        print("HERE", info)
+        self.con.execute(
+            "UPDATE step SET rescheduled_info = CASE rescheduled_info"
+            " WHEN '' THEN :info ELSE (rescheduled_info || '\n' || :info) END"
+            " WHERE node = :i",
+            {"info": info, "i": self.i},
+        )
+
+    def clear_rescheduled_info(self):
+        self.con.execute("UPDATE step SET rescheduled_info = '' WHERE node = ?", (self.i,))
 
     def get_validate_amended(self) -> bool:
         sql = "SELECT validate_amended FROM step WHERE node = ?"
@@ -732,7 +744,7 @@ class Step(Node):
         # Queue the job.
         logger.info("Queue %s", job.name)
         self.set_state(StepState.QUEUED)
-        self.set_rescheduled_info("")
+        self.clear_rescheduled_info()
         self.set_validate_amended(False)
         self.workflow.job_queue.put_nowait(job)
         self.workflow.job_queue_changed.set()
@@ -762,7 +774,7 @@ class Step(Node):
         - output files that are in state BUILT
         """
         # Clear rescheduled_info
-        self.set_rescheduled_info("")
+        self.clear_rescheduled_info()
 
         # Drop amended suppliers.
         rows = list(
@@ -910,7 +922,8 @@ class Step(Node):
         """Set succeeded or failed step pending (again).
 
         There can be many reasons for making a step pending,
-        e.g. inputs changes, outputs disappaered, environment variables changed.
+        e.g. inputs changes, outputs disappeared, environment variables changed.
+        This is also called when orphaned steps are recreated whose inputs are no longer valid.
 
         Parameters
         ----------
